<?php

declare(strict_types=1);

namespace Drupal\Tests\trim_html\Functional;

use Drupal\filter\Entity\FilterFormat;
use Drupal\Tests\BrowserTestBase;
use Drupal\user\Entity\User;
use PHPUnit\Framework\Attributes\Group;

/**
 * Test "Trim HTML" filter.
 */
#[Group('trim_html')]
final class FilterTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'claro';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'filter',
    'node',
    'trim_html',
  ];

  /**
   * @var \Drupal\user\Entity\User $user
   */
  protected User $user;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalCreateContentType([
      'type' => 'page',
      'name' => 'Basic page',
    ]);
    // Add a test text format.
    $format = FilterFormat::create([
      'format' => 'test_format',
      'name' => 'Test format',
    ]);
    $format->save();
    user_role_grant_permissions('authenticated', [$format->getPermissionName()]);
    // Create and log in test user.
    $this->user = $this->drupalCreateUser([
      'administer filters',
      'create page content',
      'edit any page content',
    ]);
    $this->drupalLogin($this->user);
  }

  /**
   * Test 'Trim HTML' filter.
   */
  public function testTrimHtmlFilter() : void {
    // Add test node.
    $this->drupalGet('/node/add/page');
    $edit = [
      'title[0][value]' => $this->randomString(),
      'body[0][value]' => '<p>    foo</p><p>    bar</p><p>    &nbsp;</p><p>    baz</p><p>    &nbsp;</p><p>    &nbsp;</p><p>    &nbsp;</p>',
    ];
    $this->submitForm($edit, 'Save');
    // Check original, unfiltered value.
    $this->assertSession()
      ->elementContains('css', '.field--name-body', '<p>    foo</p><p>    bar</p><p>    &nbsp;</p><p>    baz</p><p>    &nbsp;</p><p>    &nbsp;</p><p>    &nbsp;</p>') ;
    // Enable 'Trim HTML' filter.
    $this->drupalGet('/admin/config/content/formats/manage/test_format');
    $edit = [
      'filters[trim_html][status]' => TRUE,
    ];
    $this->submitForm($edit, 'Save configuration');
    // Check trimmed value.
    $this->drupalGet('/node/1');
    $this->assertSession()
      ->elementContains('css', '.field--name-body', '<p>    foo</p><p>    bar</p><p>    &nbsp;</p><p>    baz</p>') ;
  }
}
